Coverage report

File | class |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src / qutip_sampler / __init__.py | (no class) |  | 2 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | QuTipSampler |  | 24 | 0 | 0 |  | 100%
src / qutip_sampler / samplers.py | (no class) |  | 59 | 0 | 0 |  | 100%
Total |  |  | 85 | 0 | 0 |  | 100%

No items found using the specified filter.